'''Simple data loader module.

Loads data files from the "data" directory shipped with a game.

Enhancing this to handle caching etc. is left as an exercise for the reader.

Note that pyglet users should probably just add the data directory to the
pyglet.resource search path.
'''

import os
from pygame import image

data_py = os.path.abspath(os.path.dirname(__file__))
data_dir = os.path.normpath(os.path.join(data_py, '..', 'data'))

def filepath(*args):
    '''Determine the path to a file in the data directory.
    '''
    return os.path.join(data_dir, *args)

def load(filename, mode='rb'):
    '''Open a file in the data directory.

    "mode" is passed as the second arg to open().
    '''
    return open(os.path.join(data_dir, filename), mode)

cache = {}
def image_load(*args):
  key = tuple(args)
  filename = filepath('images', *args)
  try:
    surface = cache[key]
  except KeyError:
    surface = image.load(filename)
    cache[key] = surface
  return surface
